==> twinkle_0.9.orig.tar.gz: twinkle-0.9/src/parser/hdr_route.cpp <==
/*
    Copyright (C) 2005-2006  Michel de Boer <michelboer@xs4all.nl>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "definitions.h"
#include "hdr_route.h"
#include "parse_ctrl.h"

t_hdr_route::t_hdr_route() : t_header() {
	route_to_first_route = false;
}

void t_hdr_route::add_route(const t_route &r) {
	populated = true;
	route_list.push_back(r);
}

string t_hdr_route::encode(void) const {
	return (t_parser::multi_values_as_list ? encode_list() : encode_multi_header());
}

string t_hdr_route::encode_list(void) const {
	string s;

	if (!populated) return s;

	s = "Route: ";
	s += encode_value();
	s += CRLF;
	
	return s;
}

string t_hdr_route::encode_multi_header(void) const {
	string s;

	if (!populated) return s;

	for (list<t_route>::const_iterator i = route_list.begin();
	     i != route_list.end(); i++)
	{
		s += "Route: ";
		s += i->encode();
		s += CRLF;
	}

	return s;
}

string t_hdr_route::encode_value(void) const {
	string s;

	if (!populated) return s;

	for (list<t_route>::const_iterator i = route_list.begin();
	     i != route_list.end(); i++)
	{
		if (i != route_list.begin()) s += ", ";
		s += i->encode();
	}

	return s;
}

string t_hdr_route::encode_env(void) const {
	string s;
	
	s = "SIP_ROUTE=";
	s += encode_value();
	
	return s;
}

==> twinkle_1.0.orig.tar.gz: twinkle-1.0/src/parser/hdr_route.cpp <==
/*
    Copyright (C) 2005-2007  Michel de Boer <michel@twinklephone.com>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "definitions.h"
#include "hdr_route.h"
#include "parse_ctrl.h"

t_hdr_route::t_hdr_route() : t_header("Route") {
	route_to_first_route = false;
}

void t_hdr_route::add_route(const t_route &r) {
	populated = true;
	route_list.push_back(r);
}

string t_hdr_route::encode(void) const {
	return (t_parser::multi_values_as_list ? 
			t_header::encode() : encode_multi_header());
}

string t_hdr_route::encode_multi_header(void) const {
	string s;

	if (!populated) return s;

	for (list<t_route>::const_iterator i = route_list.begin();
	     i != route_list.end(); i++)
	{
		s += header_name;
		s += ": ";
		s += i->encode();
		s += CRLF;
	}

	return s;
}

string t_hdr_route::encode_value(void) const {
	string s;

	if (!populated) return s;

	for (list<t_route>::const_iterator i = route_list.begin();
	     i != route_list.end(); i++)
	{
		if (i != route_list.begin()) s += ",";
		s += i->encode();
	}

	return s;
}
